@@ -13,6 +13,7 @@ OC.L10N.register(
     "Attachment saved to Files." : "Прикачения файл е запазен във Файлове.",
     "Error while saving attachments to Files." : "Грешка при запазване на прикачените файлове във Файлове.",
     "Error while saving attachment to Files." : "Грешка при запазване на прикаченият файл във Файлове.",
+    "Message flag could not be set." : "Флага на съобщението не може да бъде настроен.",
     "Could not move message." : "Съобщението не може да бъде преместено",
     "Invalid account" : "Невалиден профил",
     "Invalid folder" : "Невалидна папка",
@@ -27,11 +28,16 @@ OC.L10N.register(
     "Could not load your message" : "Вашето съобщение не може да бъде заредено",
     "Could not load the desired message" : "Желаното съобщение не може да бъде заредено",
     "Could not load the message" : "Съобщението не може да бъде заредено",
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ново съобщение \nот {from}","%n нови съобщения\nот {from}"],
+    "Nextcloud Mail" : "Nextcloud Е-Мейл",
     "Save" : "Запазване",
     "Saved" : "Запазено",
     "Show all folders" : "Покажи всички папки",
+    "Collapse folders" : "Свиване на папките",
     "Error while deleting account." : "Грешка при изтриването на профил.",
     "Choose a file to add as attachment" : "Избери файл за прикачване",
+    "An error occurred while uploading {fname}" : "Възникна греша по време на качване на {fname}",
     "Reply" : "Отговори",
     "Send" : "Изпрати",
     "Sending …" : "Изпращане...",
@@ -53,14 +59,21 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "Неуспешни автоматични настройки. Моля, използвай ръчен режим.",
     "Creating account failed: " : "Неуспешно създаване на профил:",
     "Delete permanently" : "Изтрий завинаги",
+    "IMAP web client" : "IMAP уеб клиент",
     "Error loading message" : "Грешка при зареждане съобщението",
     "Settings" : "Настройки",
     "Forwarding to %s" : "Препращане към %s",
     "The link leads to %s" : "Връзката води до %s",
+    "Continue to %s" : "Продължи към %s",
     "Delete account" : "Изтриване на профил",
+    "Try again" : "Опитай отново",
     "New message" : "Ново съобщение",
     "Account Settings" : "Настройки на профила",
+    "Aliases" : "Псевдоними",
     "Mail address" : "Имейл адрес",
+    "Display Name" : "Име за визуализация",
+    "Account" : "Профил",
+    "Refresh" : "Опресняване",
     "Name" : "Име",
     "Mail Address" : "Имейл адрес",
     "Password" : "Парола",
