@@ -1,7 +1,7 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Correu electrónic",
+    "Mail" : "Correu electrònic",
     "Loading accounts" : "S'està carregant",
     "Error while loading the accounts." : "Error al carregar els comptes.",
     "Can not load this folder." : "No s'ha pogut carregar aquesta carpeta.",
@@ -72,6 +72,7 @@ OC.L10N.register(
     "Aliases" : "Àlies",
     "Mail address" : "Adreça de correu",
     "Display Name" : "Nom d'usuari",
+    "Delete" : "Esborra",
     "Keyboard shortcuts" : "Dreceres de teclat",
     "Speed up your Mail experience with these quick shortcuts." : "Accelera el teu us de Mail amb aquestes dreceres de teclat.",
     "Compose new message" : "Nou missatge",
@@ -79,7 +80,6 @@ OC.L10N.register(
     "Older message" : "Missatges més vells",
     "Toggle star" : "Commuta l'estrella",
     "Toggle unread" : "Commuta la lectura",
-    "Delete" : "Esborra",
     "Search" : "Cerca",
     "Refresh" : "Refresca",
     "Connect your mail account" : "Connecteu el teu compte de correu",
