@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "Correo",
     "Loading accounts" : "Cargando cuentas",
     "Error while loading the accounts." : "Se presentó un error al cargar las cuentas.",
-    "Error while loading the selected account." : "Se presentó un error al cargar la cuenta seleccionada. ",
     "Can not load this folder." : "No se puede cargar esta carpeta.",
     "Searching for {query}" : "Buscando a {query}",
     "Error while deleting message." : "Se presentó un error al borrar el mensaje.",
@@ -20,19 +19,20 @@ OC.L10N.register(
     "Invalid folder" : "Carpeta inválida",
     "Error while creating the account: " : "Se presentó un error al crear la cuenta:",
     "Unknown error" : "Error desconocido",
+    "Error while updating the account: " : "Se presentó un error al actualizar la cuenta:",
     "All inboxes" : "Todos los buzones de entrada",
     "you" : "tú",
     "Send message to {email}" : "Enviar mensaje a {email}",
     "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
-    "We couldn’t load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
-    "We couldn’t load your message" : "No fue posible cargar tu mensaje",
-    "Unable to load the desired message" : "No fue posible cargar el mensaje deseado",
-    "There was a problem loading the message" : "Se presentó un problema al cargar el mensaje",
+    "Could not load your message" : "No fue posible cargar tu mensaje",
+    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
+    "Could not load the message" : "No fue posible cargar el mensaje",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
     "Nextcloud Mail" : "Correo Nextcloud",
     "Save" : "Guardar",
+    "Saved" : "Guardado",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Compactar carpetas",
     "Error while deleting account." : "Se presetó un error al borrar la cuenta.",
@@ -45,10 +45,10 @@ OC.L10N.register(
     "Server error" : "Se presentó un error en el servidor",
     "An unknown error occurred" : "Se presentó un error desconocido",
     "Opening HTML drafts is not supported yet." : "Abrir borradores HTML aún no está soportado.",
-    "Draft saved!" : "¡Borrador guardado!",
     "No writable calendars found" : "No se encontraron calendarios editables",
     "Error while importing the calendar event" : "Se presentó un error al importar el evento del calendario",
     "Error while downloading calendar event" : "Se presentó un error al descargar el evento del calendario",
+    "& others" : "& otros",
     "Error while loading messages." : "Se presentói un error al cargar los mensajes.",
     "Error while refreshing messages." : "Se presentó un error al actualizar los mensajes.",
     "Setting up your account" : "Configura tu cuenta",
@@ -61,9 +61,9 @@ OC.L10N.register(
     "All" : "Todos",
     "Favorites" : "Favoritos",
     "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
+    "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
     "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
     "Delete permanently" : "Borrar permanentemente",
-    "& others" : "& otros",
     "Error loading message" : "Se presentó un error al cargar el mensaje",
     "Settings" : "Configuraciones ",
     "Forwarding to %s" : "Reenviando a %s",
@@ -79,6 +79,8 @@ OC.L10N.register(
     "Aliases" : "Aliases",
     "Mail address" : "Dirección de correo",
     "Display Name" : "Nombre a desplegar",
+    "Account" : "Cuenta",
+    "Delete" : "Borrar",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
     "Compose new message" : "Escribir mensaje nuevo",
@@ -86,7 +88,6 @@ OC.L10N.register(
     "Older message" : "Mensaje más antiguo",
     "Toggle star" : "Alternar favoritos",
     "Toggle unread" : "Alternar no leídos",
-    "Delete" : "Borrar",
     "Search" : "Buscar",
     "Refresh" : "Actualizar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
@@ -111,6 +112,7 @@ OC.L10N.register(
     "to" : "para",
     "cc" : "cc",
     "bcc" : "cco",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota que el correo vino de una dirección no-responda asi que tu respuesta probablemente no sea leida. ",
     "Subject" : "Asunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "Add mail account" : "Agregar cuenta de correo",
@@ -119,7 +121,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Show images from this sender" : "Mostrar imagenes de este remitente",
     "Forward" : "Reenviar",
-    "No messages in this folder!" : "¡No hay mensajes en esta carpeta!",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
     "Import into calendar" : "Importar al calendario",
