@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "Correo",
     "Loading accounts" : "Cargando cuentas",
     "Error while loading the accounts." : "Se presentó un error al cargar las cuentas.",
-    "Error while loading the selected account." : "Se presentó un error al cargar la cuenta seleccionada. ",
     "Can not load this folder." : "No se puede cargar esta carpeta.",
     "Searching for {query}" : "Buscando a {query}",
     "Error while deleting message." : "Se presentó un error al borrar el mensaje.",
@@ -24,11 +23,7 @@ OC.L10N.register(
     "you" : "tú",
     "Send message to {email}" : "Enviar mensaje a {email}",
     "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
-    "We couldn’t load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
-    "We couldn’t load your message" : "No fue posible cargar tu mensaje",
-    "Unable to load the desired message" : "No fue posible cargar el mensaje deseado",
-    "There was a problem loading the message" : "Se presentó un problema al cargar el mensaje",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
     "Nextcloud Mail" : "Correo Nextcloud",
@@ -45,7 +40,6 @@ OC.L10N.register(
     "Server error" : "Se presentó un error en el servidor",
     "An unknown error occurred" : "Se presentó un error desconocido",
     "Opening HTML drafts is not supported yet." : "Abrir borradores HTML aún no está soportado.",
-    "Draft saved!" : "¡Borrador guardado!",
     "No writable calendars found" : "No se encontraron calendarios editables",
     "Error while importing the calendar event" : "Se presentó un error al importar el evento del calendario",
     "Error while downloading calendar event" : "Se presentó un error al descargar el evento del calendario",
@@ -79,6 +73,7 @@ OC.L10N.register(
     "Aliases" : "Aliases",
     "Mail address" : "Dirección de correo",
     "Display Name" : "Nombre a desplegar",
+    "Delete" : "Borrar",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
     "Compose new message" : "Escribir mensaje nuevo",
@@ -86,7 +81,6 @@ OC.L10N.register(
     "Older message" : "Mensaje más antiguo",
     "Toggle star" : "Alternar favoritos",
     "Toggle unread" : "Alternar no leídos",
-    "Delete" : "Borrar",
     "Search" : "Buscar",
     "Refresh" : "Actualizar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
@@ -119,7 +113,6 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Show images from this sender" : "Mostrar imagenes de este remitente",
     "Forward" : "Reenviar",
-    "No messages in this folder!" : "¡No hay mensajes en esta carpeta!",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
     "Import into calendar" : "Importar al calendario",
