@@ -65,6 +65,7 @@ OC.L10N.register(
     "Creating account failed: " : "Aanmaken account mislukt:",
     "Delete permanently" : "Definitief verwijderen",
     "IMAP web client" : "IMAP web client",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Gebruiksvriendelijke e-mailclient die verbindt met je mailserver via IMAP en SMTP.",
     "Error loading message" : "Fout bij laden bericht",
     "Settings" : "Instellingen",
     "Forwarding to %s" : "Doorsturen aan %s",
@@ -81,6 +82,7 @@ OC.L10N.register(
     "Mail address" : "E-mailadres",
     "Display Name" : "Weergavenaam",
     "Account" : "Account",
+    "Toggle read" : "Omschakelen leesmodus",
     "Delete" : "Verwijderen",
     "Keyboard shortcuts" : "Sneltoetsen",
     "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mail-ervaring met deze handige snelkoppelingen.",
