@@ -29,6 +29,7 @@ OC.L10N.register(
     "Could not load the desired message" : "Nie można wczytać żądanej wiadomości",
     "Could not load the message" : "Nie można załadować wiadomości",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nowa wiadomość\nod {from}","%n nowe wiadomości \nod {from}","%n nowych wiadomości \nod {from}","%n nowych wiadomości \nod {from}"],
     "Nextcloud Mail" : "Poczta Nextcloud",
     "Save" : "Zapisz",
     "Saved" : "Zapisano",
@@ -63,6 +64,8 @@ OC.L10N.register(
     "Updating account failed: " : "Błąd aktualizacji konta: ",
     "Creating account failed: " : "Utworzenie konta nie powiodło się:",
     "Delete permanently" : "Trwale usuń",
+    "IMAP web client" : "Klient webowy IMAP",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Łatwy w użytkowaniu klient IMAP i SMTP, który łączy się z Twoim serwerem pocztowym.",
     "Error loading message" : "Błąd podczas ładowania wiadomości",
     "Settings" : "Ustawienia",
     "Forwarding to %s" : "Prześlij do %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Mail address" : "Adres mailowy",
     "Display Name" : "Wyświetlana nazwa",
     "Account" : "Konto",
+    "Toggle read" : "Oznacz jako przeczytane/nieprzeczytane",
     "Delete" : "Usuń",
     "Keyboard shortcuts" : "Skróty klawiaturowe",
     "Speed up your Mail experience with these quick shortcuts." : "Aby przyspieszyć korzystanie z Poczty użyj tych skrótów.",
