@@ -64,6 +64,8 @@ OC.L10N.register(
     "Updating account failed: " : "Uppdatering av konto misslyckades:",
     "Creating account failed: " : "Misslyckades att skapa kontot:",
     "Delete permanently" : "Radera permanent",
+    "IMAP web client" : "IMAP webbklient",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Lättanvänd e-postklient som ansluter till din e-postserver via IMAP och SMTP.",
     "Error loading message" : "Fel vid inläsning av meddelande",
     "Settings" : "Inställningar",
     "Forwarding to %s" : "Vidarebefordrar till %s",
@@ -80,6 +82,7 @@ OC.L10N.register(
     "Mail address" : "E-postadress",
     "Display Name" : "Visningsnamn",
     "Account" : "Konto",
+    "Toggle read" : "Växla läst",
     "Delete" : "Ta bort",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Speed up your Mail experience with these quick shortcuts." : "Snabba upp din E-post-upplevelse med dessa genvägar.",
@@ -112,6 +115,7 @@ OC.L10N.register(
     "to" : "till",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observera att avsändaren är en noreply-adress så ditt svar kommer antagligen inte att läsas.",
     "Subject" : "Ämne",
     "Save all to Files" : "Spara allt till dina filer",
     "Add mail account" : "Lägg till e-postkonto",
@@ -120,6 +124,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Bilderna har blockerats av säkerhetsskäl.",
     "Show images from this sender" : "Visa bilder från denna avsändare",
     "Forward" : "Vidarebefodra",
+    "No messages in this folder" : "Inga meddelanden i denna mapp",
     "Upload attachment" : "Ladda upp bilaga",
     "Add attachment from Files" : "Lägg till bilaga från Filer",
     "Import into calendar" : "Importera till kalender",
