@@ -145,7 +145,7 @@ class IspDbConfigurationDetector {
 	 */
 	private function testImapConfiguration(array $imap, string $email, string $password, string $name) {
 		$host = $imap['hostname'];
-		$port = $imap['port'];
+		$port = (int) $imap['port'];
 		$encryptionProtocol = 'none';
 		if ($imap['socketType'] === 'SSL') {
 			$encryptionProtocol = 'ssl';
